==> phpMyGPX-0.3.tar.bz2: phpmygpx/languages/english.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

// no direct access
defined( '_VALID_OSM' ) or die( 'Restricted access' );

// Site page note found
define( '_404', 'We\'re sorry but the page you requested could not be found.' );
define( '_404_RTS', 'Return to site' );

// common
DEFINE('_APP_NAME','phpMyGPX');
DEFINE('_HTML_TITLE','phpMyGPX ::: track point managment');

DEFINE('_DATE_FORMAT_LC',"%A, %d %B %Y"); //Uses PHP's strftime Command Format
DEFINE('_DATE_FORMAT_LC2',"%A, %d %B %Y %H:%M");
DEFINE('_DATE_FORMAT_LC3',"%d %B %Y %H:%M:%S");
DEFINE('_TIME_FORMAT_LC4',"%H:%M:%S h");

DEFINE('_LANGUAGE','en');
DEFINE('_NOT_AUTH','You are not authorized to view this resource.');
DEFINE('_DO_LOGIN','You need to login.');
DEFINE('_VALID_AZ09',"Please enter a valid %s.  No spaces, more than %d characters and contain 0-9,a-z,A-Z");
DEFINE('_VALID_AZ09_USER',"Please enter a valid %s.  More than %d characters and contain 0-9,a-z,A-Z");
DEFINE('_CMN_YES','Yes');
DEFINE('_CMN_NO','No');
DEFINE('_CMN_SHOW','Show');
DEFINE('_CMN_HIDE','Hide');

DEFINE('_CMN_NAME','Name');
DEFINE('_CMN_DESCRIPTION','Description');
DEFINE('_CMN_SAVE','Save');
DEFINE('_CMN_APPLY','Apply');
DEFINE('_CMN_CANCEL','Cancel');
DEFINE('_CMN_PRINT','Print');
DEFINE('_CMN_PDF','PDF');
DEFINE('_CMN_EMAIL','E-mail');
DEFINE('_ICON_SEP','|');
DEFINE('_CMN_PARENT','Parent');
DEFINE('_CMN_ORDERING','Ordering');
DEFINE('_CMN_ACCESS','Access Level');
DEFINE('_CMN_SELECT','Select');

DEFINE('_CMN_FIRST','First');
DEFINE('_CMN_LAST','Last');
DEFINE('_CMN_NEXT','Next');
DEFINE('_CMN_NEXT_ARROW'," &gt;&gt;");
DEFINE('_CMN_PREV','Prev');
DEFINE('_CMN_PREV_ARROW',"&lt;&lt; ");

DEFINE('_CMN_SORT_NONE','No Sorting');
DEFINE('_CMN_SORT_ASC','Sort Ascending');
DEFINE('_CMN_SORT_DESC','Sort Descending');

DEFINE('_CMN_NEW','New');
DEFINE('_CMN_NONE','None');
DEFINE('_CMN_LEFT','Left');
DEFINE('_CMN_RIGHT','Right');
DEFINE('_CMN_CENTER','Center');
DEFINE('_CMN_ARCHIVE','Archive');
DEFINE('_CMN_UNARCHIVE','Unarchive');
DEFINE('_CMN_TOP','Top');
DEFINE('_CMN_BOTTOM','Bottom');

DEFINE('_CMN_PUBLISHED','Published');
DEFINE('_CMN_UNPUBLISHED','Unpublished');

DEFINE('_CMN_EDIT_HTML','Edit HTML');
DEFINE('_CMN_EDIT_CSS','Edit CSS');

DEFINE('_CMN_DELETE','Delete');

DEFINE('_CMN_FOLDER','Folder');
DEFINE('_CMN_SUBFOLDER','Sub-folder');
DEFINE('_CMN_OPTIONAL','Optional');
DEFINE('_CMN_REQUIRED','Required');


DEFINE('_CMN_SCRIPT_EXEC_TIME','Page generated in ');

DEFINE('_CMN_NOT_IMPLEMENTED','This feature isn\'t implemented yet.');
DEFINE('_CMN_CONTINUE','Continue');
DEFINE('_CMN_WARNING','Warning!');
DEFINE('_CMN_PAGE','Page');

DEFINE('_CMN_RANGE','Range');
DEFINE('_CMN_INSERTED','inserted');
DEFINE('_CMN_PUBLIC','public');
DEFINE('_CMN_VISIBLE','visible');
DEFINE('_CMN_USER_ID','User ID');
DEFINE('_CMN_GPX_ID','GPX ID');
DEFINE('_CMN_BM_ID','Bm ID');
DEFINE('_CMN_BM_NAME','Bookmark name');
DEFINE('_CMN_FILE_NAME','File name');
DEFINE('_CMN_FILE_SIZE','File size');
DEFINE('_CMN_DATE','Date');
DEFINE('_CMN_LAT','Latitude');
DEFINE('_CMN_LON','Longitude');
DEFINE('_CMN_ALT','Altitude');
DEFINE('_CMN_COURSE','Course');
DEFINE('_CMN_SPEED','Speed');
DEFINE('_CMN_FIX','Sat Fix');
DEFINE('_CMN_SAT','Satellites');
DEFINE('_CMN_HDOP','HDOP');
DEFINE('_CMN_PDOP','PDOP');


/** installation */
DEFINE('_INST_OSM_SETUP','phpMyGPX-Setup: ');
DEFINE('_INST_WELCOME','Welcome');
DEFINE('_INST_DB_INST','Database installation');
DEFINE('_INST_DONE','Installation done');

DEFINE('_INST_GUIDED','You will be guided through all steps of installation process. Just follow the given instructions.');
DEFINE('_INST_MAN_INTRO','<b>Important: </b><span style="color:red">Did you alter the configuration file <i>"config.inc.php"</i> ? If not, please do so before proceeding!</span><br>
Just open the file in your favorite text editor (e.g. Notepad), set variables to your needs, save the config file and continue with reloading <b>this</b> page within your browser ([F5] key or "Reload" button).');
DEFINE('_INST_MAN_LOGIN','If you have <b>root access</b> to your database, just enter the password below.<br>
For later usage an user with less privileges will be used for security reasons and will be created by this install routine. His login has to be set in the config file.<br><br>
If your database is <b>shared hosted</b>, you may have only one user account. In this case, please use his account data for <b>both</b> the config file <b>and</b> this installation script.'); 

DEFINE('_INST_DB_ACCOUNT','MySQL account data ');
DEFINE('_INST_DB_HOST','Host name');
DEFINE('_INST_DB_USER','User name');
DEFINE('_INST_DB_PASSWORD','Password');
DEFINE('_INST_MODE','Installation mode');
DEFINE('_INST_MODE_NEW','New/fresh installation');
DEFINE('_INST_MODE_UPGR3','Upgrade to version 0.3');
DEFINE('_INST_MODE_NEW_DESC',' (database and all tables will be created, if not existent)');
DEFINE('_INST_MODE_UPGR3_DESC',' (existing tables will be altered and missing ones will be created)');
DEFINE('_INST_DB_CREATE_SETUP','Create and setup database ');
DEFINE('_INST_PROG_INST','Your MySQL database and all tables will be created...');
DEFINE('_INST_DB_CONN_ERROR','Connection to database server failed. ');
DEFINE('_INST_UPGR3_ADD_BOOKM_TBL','Table for bookmarks was created.');
DEFINE('_INST_UPGR3_ADD_WAYPTS_TBL','Table for waypoints was created.');
DEFINE('_INST_PROG_DB','Database was created.');
DEFINE('_INST_PROG_DONE','<b>CONGRATULATIONS!</b> You successfully installed the application!');
DEFINE('_INST_PROG_TEST','Last test successfully done.');
DEFINE('_INST_ERROR','An error occured. Try to solve the problem and reload this script!');
DEFINE('_INST_DB_ERROR','Error in query: ');
DEFINE('_INST_DB_STAT','Statistics for database ');

/** html.classes.php */
DEFINE('_MENU_GPX','GPX file');
DEFINE('_MENU_GPX_VIEW','view GPX');
DEFINE('_MENU_TRKPT_VIEW','view Trackpoints');
DEFINE('_MENU_GPX_DETAILS','details');
DEFINE('_MENU_GPX_IMAGE','image');
DEFINE('_MENU_GPX_UPL','upload GPX');
DEFINE('_MENU_GPX_IMPORT','import');
DEFINE('_MENU_GPX_EXPORT','export');
DEFINE('_MENU_GPX_DOWNL','download');
DEFINE('_MENU_GPX_DELETE','delete');
DEFINE('_MENU_GPX_SEARCH','search GPX');
DEFINE('_MENU_TRKPT_SEARCH','search Trackpoints');

DEFINE('_MENU_HOME','Home');
DEFINE('_MENU_ABOUT','About...');
DEFINE('_MENU_BOOKMARK','Bookmarks');
DEFINE('_MENU_MAP','Map');
DEFINE('_MENU_MISC','Misc');
DEFINE('_MENU_DB','database');
DEFINE('_MENU_DB_STAT','Stats');
DEFINE('_MENU_LOGIN','LOGIN');
DEFINE('_MENU_LOGOUT','LOGOUT');

/** index.php */
DEFINE('_HOME_WELCOME_TO','Welcome to ');
DEFINE('_HOME_INTRO','To do: Intro');
DEFINE('_LOGIN_FAILED','Login failed. Your password is not correct.');
DEFINE('_LOGIN_SUCCESS','You have successfully Logged In');
DEFINE('_LOGOUT_SUCCESS','You have successfully Logged Out');
DEFINE('_LOGIN_DESCRIPTION','To access the Admin features of this site please Login:');

/** traces.php */
DEFINE('_TRC_NO_TRKPTS_IN_DB','No track points available.');
DEFINE('_TRC_NO_GPX_IN_DB','No GPX files in database available.');
DEFINE('_TRC_GPX_DOES_NOT_EXIST','This GPX file does not exist!');
DEFINE('_TRC_DETAILS_OF_GPX','Statistics and details of GPX file # ');
DEFINE('_TRC_APPROX_DIST', 'approx. distance');
DEFINE('_TRC_TRIP_TIME', 'trip time');
DEFINE('_TRC_AVG_SPEED', 'average speed');
DEFINE('_TRC_TRACK', 'Track ');
DEFINE('_TRC_HALT', 'Halt: ');
DEFINE('_TRC_TOTAL', 'Total');
DEFINE('_TRC_DETAILS_CHART_SPLIT','The elevation chart was split due to breaks in the track:');
DEFINE('_TRC_SHOW_MAP','Show map');
DEFINE('_TRC_SHOW_OSM_MAP','Show map on OSM');
DEFINE('_TRC_USE_DP_FOR_SEARCH','Please use decimal points for float numbers.');
DEFINE('_TRC_CHOOSE_SEARCH_FILTER','Choose filter for searching: ');
DEFINE('_TRC_CHOOSE_UPL_FILE','Choose a file to upload: ');
DEFINE('_TRC_UPL_ERROR','File upload error: ');
DEFINE('_TRC_UPL_SUCCESS','File successfully uploaded: ');
DEFINE('_TRC_READING_FILE','Reading file "<i>%1%</i>"...');
DEFINE('_TRC_FILE_ERROR','File open error!');
DEFINE('_TRC_WPTS_PROCESSED',' Waypoints processed.');
DEFINE('_TRC_TRKPTS_PROCESSED',' Trackpoints processed.');
DEFINE('_TRC_REALLY_DELETE','Do you really want to DELETE this GPX file <br />and all included track points?<br />There\'s NO undo function!');
DEFINE('_TRC_CONFIRM_DELETE','To confirm deletion please type "Yes".');
DEFINE('_TRC_NO_CONFIRM_DELETE','You aborted deleting.');
DEFINE('_TRC_WPT_DELETED','%1% waypoints deleted.');
DEFINE('_TRC_TRKPT_DELETED','%1% trackpoints deleted.');
DEFINE('_TRC_GPX_DELETED','%1% GPX files deleted.');
DEFINE('_TRC_EXPORT_AS_GPX','export as file in GPX format');

/** traces.html.php */

/** bookmark.php */
DEFINE('_BOOKM_NONE_IN_DB','No bookmarks in database available.');
DEFINE('_MENU_BOOKM_VIEW','View bookmarks');
DEFINE('_MENU_BOOKM_ADD','Add bookmark');
DEFINE('_MENU_BOOKM_DELETE','Delete bookmark');
DEFINE('_BOOKM_ADDED','Bookmark was added.');
DEFINE('_BOOKM_NO_URL','There\'s no URL for this bookmark.');
DEFINE('_BOOKM_DELETED','Bookmark was deleted.');

/** database.php */
DEFINE('_DB_GPX_AVAILABLE',' GPX files found in database.');
DEFINE('_DB_WPTS_AVAILABLE',' waypoints found in database.');
DEFINE('_DB_TRKPTS_AVAILABLE',' trackpoints found in database.');
DEFINE('_DB_DAYS_AVAILABLE',' days found in database.');
DEFINE('_DB_BOOKM_AVAILABLE',' bookmarks found in database.');
DEFINE('_DB_TOTAL_DISTANCE',' km total distance');

/** about.php */
DEFINE('_ABOUT_CREDITS','Credits');
DEFINE('_ABOUT_LICENSE','License');
DEFINE('_UPDATE_CHECK_DISABLED','Check for updates has been disabled.');
DEFINE('_UPDATE_AVAIL','An update of this software is available.');
DEFINE('_NO_UPDATE_AVAIL','No update available.');
DEFINE('_UPDATE_SERVER_ERROR404','The update server returned error 404 (Document not found).');
DEFINE('_UPDATE_SERVER_CONN_ERROR','Connection to update server failed.');

/** map.php */
DEFINE('_MAP_AREA_TRKPT','view all trackpoints of current map area');
DEFINE('_MAP_JOSM_EDIT','edit with JOSM');
DEFINE('_MAP_ADD_BOOKM','create bookmark');
DEFINE('_MAP_JS_BOOKM_NAME','Name of the bookmark: ');

/** graph.php */
DEFINE('_CHART_ELEVATION_TITLE', 'Elevation chart');
DEFINE('_CHART_AXIS_TIME', 'time');
DEFINE('_CHART_AXIS_ELE', 'elevation');

// DO NOT edit anything below this line!
include(_PATH ."version.inc.php");
?>

==> phpMyGPX-0.3.1.tar.bz2: phpmygpx/languages/english.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

// no direct access
defined( '_VALID_OSM' ) or die( 'Restricted access' );

// Site page note found
define( '_404', 'We\'re sorry but the page you requested could not be found.' );
define( '_404_RTS', 'Return to site' );

// common
DEFINE('_APP_NAME','phpMyGPX');
DEFINE('_HTML_TITLE','phpMyGPX ::: track point managment');

DEFINE('_DATE_FORMAT_LC',"%Y-%m-%d"); //Uses PHP's strftime Command Format
DEFINE('_DATE_FORMAT_LC2',"%A, %d %B %Y %H:%M");
DEFINE('_DATE_FORMAT_LC3',"%Y-%m-%d %H:%M:%S");
DEFINE('_TIME_FORMAT_LC4',"%H:%M:%S h");

DEFINE('_LANGUAGE','en');
DEFINE('_NOT_AUTH','You are not authorized to view this resource.');
DEFINE('_DO_LOGIN','You need to login.');
DEFINE('_VALID_AZ09',"Please enter a valid %s.  No spaces, more than %d characters and contain 0-9,a-z,A-Z");
DEFINE('_VALID_AZ09_USER',"Please enter a valid %s.  More than %d characters and contain 0-9,a-z,A-Z");
DEFINE('_CMN_YES','Yes');
DEFINE('_CMN_NO','No');
DEFINE('_CMN_SHOW','Show');
DEFINE('_CMN_HIDE','Hide');

DEFINE('_CMN_NAME','Name');
DEFINE('_CMN_DESCRIPTION','Description');
DEFINE('_CMN_SAVE','Save');
DEFINE('_CMN_APPLY','Apply');
DEFINE('_CMN_CANCEL','Cancel');
DEFINE('_CMN_PRINT','Print');
DEFINE('_CMN_PDF','PDF');
DEFINE('_CMN_EMAIL','E-mail');
DEFINE('_ICON_SEP','|');
DEFINE('_CMN_PARENT','Parent');
DEFINE('_CMN_ORDERING','Ordering');
DEFINE('_CMN_ACCESS','Access Level');
DEFINE('_CMN_SELECT','Select');

DEFINE('_CMN_FIRST','First');
DEFINE('_CMN_LAST','Last');
DEFINE('_CMN_NEXT','Next');
DEFINE('_CMN_NEXT_ARROW'," &gt;&gt;");
DEFINE('_CMN_PREV','Prev');
DEFINE('_CMN_PREV_ARROW',"&lt;&lt; ");

DEFINE('_CMN_SORT_NONE','No Sorting');
DEFINE('_CMN_SORT_ASC','Sort Ascending');
DEFINE('_CMN_SORT_DESC','Sort Descending');

DEFINE('_CMN_NEW','New');
DEFINE('_CMN_NONE','None');
DEFINE('_CMN_LEFT','Left');
DEFINE('_CMN_RIGHT','Right');
DEFINE('_CMN_CENTER','Center');
DEFINE('_CMN_ARCHIVE','Archive');
DEFINE('_CMN_UNARCHIVE','Unarchive');
DEFINE('_CMN_TOP','Top');
DEFINE('_CMN_BOTTOM','Bottom');

DEFINE('_CMN_PUBLISHED','Published');
DEFINE('_CMN_UNPUBLISHED','Unpublished');

DEFINE('_CMN_EDIT_HTML','Edit HTML');
DEFINE('_CMN_EDIT_CSS','Edit CSS');

DEFINE('_CMN_DELETE','Delete');

DEFINE('_CMN_FOLDER','Folder');
DEFINE('_CMN_SUBFOLDER','Sub-folder');
DEFINE('_CMN_OPTIONAL','Optional');
DEFINE('_CMN_REQUIRED','Required');


DEFINE('_CMN_SCRIPT_EXEC_TIME','Page generated in ');

DEFINE('_CMN_NOT_IMPLEMENTED','This feature isn\'t implemented yet.');
DEFINE('_CMN_BACK','Back');
DEFINE('_CMN_CONTINUE','Continue');
DEFINE('_CMN_WARNING','Warning!');
DEFINE('_CMN_PAGE','Page');

DEFINE('_CMN_RANGE','Range');
DEFINE('_CMN_INSERTED','inserted');
DEFINE('_CMN_PUBLIC','public');
DEFINE('_CMN_VISIBLE','visible');
DEFINE('_CMN_USER_ID','User ID');
DEFINE('_CMN_GPX_ID','GPX ID');
DEFINE('_CMN_BM_ID','Bm ID');
DEFINE('_CMN_BM_NAME','Bookmark name');
DEFINE('_CMN_FILE_NAME','File name');
DEFINE('_CMN_FILE_SIZE','File size');
DEFINE('_CMN_DATE','Date');
DEFINE('_CMN_LAT','Latitude');
DEFINE('_CMN_LON','Longitude');
DEFINE('_CMN_ALT','Altitude');
DEFINE('_CMN_COURSE','Course');
DEFINE('_CMN_SPEED','Speed');
DEFINE('_CMN_FIX','Sat Fix');
DEFINE('_CMN_SAT','Satellites');
DEFINE('_CMN_HDOP','HDOP');
DEFINE('_CMN_PDOP','PDOP');


/** installation */
DEFINE('_INST_OSM_SETUP','phpMyGPX-Setup: ');
DEFINE('_INST_WELCOME','Welcome');
DEFINE('_INST_DB_INST','Database installation');
DEFINE('_INST_DONE','Installation done');

DEFINE('_INST_GUIDED','You will be guided through all steps of installation process. Just follow the given instructions.');
DEFINE('_INST_MAN_INTRO','<b>Important: </b><span style="color:red">Did you alter the configuration file <i>"config.inc.php"</i> ? If not, please do so before proceeding!</span><br>
Just open the file in your favorite text editor (e.g. Notepad), set variables to your needs, save the config file and continue with reloading <b>this</b> page within your browser ([F5] key or "Reload" button).');
DEFINE('_INST_MAN_LOGIN','If you have <b>root access</b> to your database, just enter the password below.<br>
For later usage an user with less privileges will be used for security reasons and will be created by this install routine. His login has to be set in the config file.<br><br>
If your database is <b>shared hosted</b>, you may have only one user account. In this case, please use his account data for <b>both</b> the config file <b>and</b> this installation script.'); 

DEFINE('_INST_DB_ACCOUNT','MySQL account data ');
DEFINE('_INST_DB_HOST','Host name');
DEFINE('_INST_DB_USER','User name');
DEFINE('_INST_DB_PASSWORD','Password');
DEFINE('_INST_MODE','Installation mode');
DEFINE('_INST_MODE_NEW','New/fresh installation');
DEFINE('_INST_MODE_UPGR3','Upgrade to version 0.3');
DEFINE('_INST_MODE_NEW_DESC',' (database and all tables will be created, if not existent)');
DEFINE('_INST_MODE_UPGR3_DESC',' (existing tables will be altered and missing ones will be created)');
DEFINE('_INST_DB_CREATE_SETUP','Create and setup database ');
DEFINE('_INST_PROG_INST','Your MySQL database and all tables will be created...');
DEFINE('_INST_DB_CONN_ERROR','Connection to database server failed. ');
DEFINE('_INST_UPGR3_ADD_BOOKM_TBL','Table for bookmarks was created.');
DEFINE('_INST_UPGR3_ADD_WAYPTS_TBL','Table for waypoints was created.');
DEFINE('_INST_PROG_DB','Database was created.');
DEFINE('_INST_PROG_DONE','<b>CONGRATULATIONS!</b> You successfully installed the application!');
DEFINE('_INST_PROG_TEST','Last test successfully done.');
DEFINE('_INST_ERROR','An error occured. Try to solve the problem and reload this script!');
DEFINE('_INST_DB_ERROR','Error in query: ');
DEFINE('_INST_DB_STAT','Statistics for database ');

/** html.classes.php */
DEFINE('_MENU_GPX','GPX file');
DEFINE('_MENU_GPX_VIEW','view GPX');
DEFINE('_MENU_TRKPT_VIEW','view Trackpoints');
DEFINE('_MENU_GPX_DETAILS','details');
DEFINE('_MENU_GPX_IMAGE','image');
DEFINE('_MENU_GPX_UPL','upload GPX');
DEFINE('_MENU_GPX_IMPORT','import');
DEFINE('_MENU_GPX_EXPORT','export');
DEFINE('_MENU_GPX_DOWNL','download');
DEFINE('_MENU_GPX_DELETE','delete');
DEFINE('_MENU_GPX_SEARCH','search GPX');
DEFINE('_MENU_TRKPT_SEARCH','search Trackpoints');

DEFINE('_MENU_HOME','Home');
DEFINE('_MENU_ABOUT','About...');
DEFINE('_MENU_BOOKMARK','Bookmarks');
DEFINE('_MENU_MAP','Map');
DEFINE('_MENU_MISC','Misc');
DEFINE('_MENU_DB','database');
DEFINE('_MENU_DB_STAT','Stats');
DEFINE('_MENU_LOGIN','LOGIN');
DEFINE('_MENU_LOGOUT','LOGOUT');

/** index.php */
DEFINE('_HOME_WELCOME_TO','Welcome to ');
DEFINE('_HOME_INTRO','To do: Intro');
DEFINE('_LOGIN_FAILED','Login failed. Your password is not correct.');
DEFINE('_LOGIN_SUCCESS','You have successfully Logged In');
DEFINE('_LOGOUT_SUCCESS','You have successfully Logged Out');
DEFINE('_LOGIN_DESCRIPTION','To access the Admin features of this site please Login:');

/** traces.php */
DEFINE('_TRC_NO_TRKPTS_IN_DB','No track points available.');
DEFINE('_TRC_NO_GPX_IN_DB','No GPX files in database available.');
DEFINE('_TRC_GPX_DOES_NOT_EXIST','This GPX file does not exist!');
DEFINE('_TRC_DETAILS_OF_GPX','Statistics and details of GPX file # ');
DEFINE('_TRC_APPROX_DIST', 'approx. distance');
DEFINE('_TRC_TRIP_TIME', 'trip time');
DEFINE('_TRC_AVG_SPEED', 'average speed');
DEFINE('_TRC_TRACK', 'Track ');
DEFINE('_TRC_HALT', 'Halt: ');
DEFINE('_TRC_TOTAL', 'Total');
DEFINE('_TRC_DETAILS_CHART_SPLIT','The elevation chart was split due to breaks in the track:');
DEFINE('_TRC_SHOW_MAP','Show map');
DEFINE('_TRC_SHOW_OSM_MAP','Show map on OSM');
DEFINE('_TRC_USE_DP_FOR_SEARCH','Please use decimal points for float numbers.');
DEFINE('_TRC_CHOOSE_SEARCH_FILTER','Choose filter for searching: ');
DEFINE('_TRC_CHOOSE_UPL_FILE','Choose a file to upload: ');
DEFINE('_TRC_MAY_TAKE_SECONDS','This may take some seconds.');
DEFINE('_TRC_UPL_ERROR','File upload error: ');
DEFINE('_TRC_UPL_SUCCESS','File successfully uploaded: ');
DEFINE('_TRC_READING_FILE','Reading file "<i>%1%</i>"...');
DEFINE('_TRC_FILE_ERROR','File open error!');
DEFINE('_TRC_WPTS_PROCESSED',' Waypoints processed.');
DEFINE('_TRC_TRKPTS_PROCESSED',' Trackpoints processed.');
DEFINE('_TRC_REALLY_DELETE','Do you really want to DELETE this GPX file <br />and all included track points?<br />There\'s NO undo function!');
DEFINE('_TRC_CONFIRM_DELETE','To confirm deletion please type "Yes".');
DEFINE('_TRC_NO_CONFIRM_DELETE','You aborted deleting.');
DEFINE('_TRC_WPT_DELETED','%1% waypoints deleted.');
DEFINE('_TRC_TRKPT_DELETED','%1% trackpoints deleted.');
DEFINE('_TRC_GPX_DELETED','%1% GPX files deleted.');
DEFINE('_TRC_EXPORT_AS_GPX','export as file in GPX format');

/** traces.html.php */

/** bookmark.php */
DEFINE('_BOOKM_NONE_IN_DB','No bookmarks in database available.');
DEFINE('_MENU_BOOKM_VIEW','View bookmarks');
DEFINE('_MENU_BOOKM_ADD','Add bookmark');
DEFINE('_MENU_BOOKM_DELETE','Delete bookmark');
DEFINE('_BOOKM_ADDED','Bookmark was added.');
DEFINE('_BOOKM_NO_URL','There\'s no URL for this bookmark.');
DEFINE('_BOOKM_DELETED','Bookmark was deleted.');

/** database.php */
DEFINE('_DB_GPX_AVAILABLE',' GPX files found in database.');
DEFINE('_DB_WPTS_AVAILABLE',' waypoints found in database.');
DEFINE('_DB_TRKPTS_AVAILABLE',' trackpoints found in database.');
DEFINE('_DB_DAYS_AVAILABLE',' days found in database.');
DEFINE('_DB_BOOKM_AVAILABLE',' bookmarks found in database.');
DEFINE('_DB_TOTAL_DISTANCE',' km total distance');

/** about.php */
DEFINE('_ABOUT_CREDITS','Credits');
DEFINE('_ABOUT_LICENSE','License');
DEFINE('_UPDATE_CHECK_DISABLED','Check for updates has been disabled.');
DEFINE('_UPDATE_AVAIL','An update of this software is available.');
DEFINE('_NO_UPDATE_AVAIL','No update available.');
DEFINE('_UPDATE_SERVER_ERROR404','The update server returned error 404 (Document not found).');
DEFINE('_UPDATE_SERVER_CONN_ERROR','Connection to update server failed.');

/** map.php */
DEFINE('_MAP_AREA_TRKPT','view all trackpoints of current map area');
DEFINE('_MAP_JOSM_EDIT','edit with JOSM');
DEFINE('_MAP_ADD_BOOKM','create bookmark');
DEFINE('_MAP_JS_BOOKM_NAME','Name of the bookmark: ');

/** graph.php */
DEFINE('_CHART_ELEVATION_TITLE', 'Elevation chart');
DEFINE('_CHART_AXIS_TIME', 'time');
DEFINE('_CHART_AXIS_ELE', 'elevation');

// DO NOT edit anything below this line!
include(_PATH ."version.inc.php");
?>
